# puffotter

|master|develop|
|:----:|:-----:|
|[![build status](https://gitlab.namibsun.net/namibsun/python/puffotter/badges/master/build.svg)](https://gitlab.namibsun.net/namibsun/python/puffotter/commits/master)|[![build status](https://gitlab.namibsun.net/namibsun/python/puffotter/badges/develop/build.svg)](https://gitlab.namibsun.net/namibsun/python/puffotter/commits/develop)|

![Logo](resources/logo/logo-readme.png)

A python library for common convenience functions.

## Further Information

* [Changelog](CHANGELOG)
* [License (GPLv3)](LICENSE)
* [Gitlab](https://gitlab.namibsun.net/namibsun/python/puffotter)
* [Github](https://github.com/namboy94/puffotter)
* [Progstats](https://progstats.namibsun.net/projects/puffotter)
* [PyPi](https://pypi.org/project/puffotter)
